==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/NonStd/NonStdGetPID.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NonStdGetPID_46getPID_35	((void*)startLabel+8)
#define CT_v162	((void*)startLabel+36)
#define F0_NonStdGetPID_46getPID_35	((void*)startLabel+44)
#define CT_v164	((void*)startLabel+80)
#define ST_v160	((void*)startLabel+100)
#define ST_v163	((void*)startLabel+113)
#define ST_v161	((void*)startLabel+133)
extern Node TM_NonStdGetPID[];
void FR_NonStdGetPID_46getPID_35(void);
extern Node TM_NonStdGetPID[];
extern Node FN_NHC_46Internal_46_95mkIOok0[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v162)
,	/* FN_NonStdGetPID_46getPID_35: (byte 0) */
  useLabel(TM_NonStdGetPID)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NonStdGetPID_46getPID_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v161)
,	/* CT_v162: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NonStdGetPID_46getPID_35: (byte 0) */
  CAPTAG(useLabel(FN_NonStdGetPID_46getPID_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v164)
,};
Node FN_NonStdGetPID_46getPID[] = {
  useLabel(TM_NonStdGetPID)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v163)
,	/* CT_v164: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_NonStdGetPID_46getPID[] = {
  VAPTAG(useLabel(FN_NonStdGetPID_46getPID))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_NonStdGetPID_46getPID_35)
,};
Node PM_NonStdGetPID[] = {
 	/* ST_v160: (byte 0) */
  bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
,	/* ST_v163: (byte 1) */
  bytes2word(0,78,111,110)
, bytes2word(83,116,100,71)
, bytes2word(101,116,80,73)
, bytes2word(68,46,103,101)
, bytes2word(116,80,73,68)
,	/* ST_v161: (byte 1) */
  bytes2word(0,78,111,110)
, bytes2word(83,116,100,71)
, bytes2word(101,116,80,73)
, bytes2word(68,46,103,101)
, bytes2word(116,80,73,68)
, bytes2word(35,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getPID" NonStdGetPID.getPID# 1 :: Prelude.() -> Prelude.Int */
extern HsInt hs_getPID(void);
#ifdef PROFILE
static SInfo pf_hs_getPID = {"NonStdGetPID","NonStdGetPID.getPID#","Prelude.Int"};
#endif
C_HEADER(FR_NonStdGetPID_46getPID_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = hs_getPID();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_getPID);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/NonStd/NonStdGetPID.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NonStdGetPID_46getPID_35	((void*)startLabel+8)
#define CT_v174	((void*)startLabel+36)
#define F0_NonStdGetPID_46getPID_35	((void*)startLabel+44)
#define CT_v176	((void*)startLabel+80)
#define ST_v172	((void*)startLabel+100)
#define ST_v175	((void*)startLabel+113)
#define ST_v173	((void*)startLabel+133)
extern Node TM_NonStdGetPID[];
void FR_NonStdGetPID_46getPID_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok0[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v174)
,	/* FN_NonStdGetPID_46getPID_35: (byte 0) */
  useLabel(TM_NonStdGetPID)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NonStdGetPID_46getPID_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50001
, useLabel(ST_v173)
,	/* CT_v174: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NonStdGetPID_46getPID_35: (byte 0) */
  CAPTAG(useLabel(FN_NonStdGetPID_46getPID_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v176)
,};
Node FN_NonStdGetPID_46getPID[] = {
  useLabel(TM_NonStdGetPID)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50001
, useLabel(ST_v175)
,	/* CT_v176: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_NonStdGetPID_46getPID[] = {
  VAPTAG(useLabel(FN_NonStdGetPID_46getPID))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_NonStdGetPID_46getPID_35)
,};
Node PM_NonStdGetPID[] = {
 	/* ST_v172: (byte 0) */
  bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
,	/* ST_v175: (byte 1) */
  bytes2word(0,78,111,110)
, bytes2word(83,116,100,71)
, bytes2word(101,116,80,73)
, bytes2word(68,46,103,101)
, bytes2word(116,80,73,68)
,	/* ST_v173: (byte 1) */
  bytes2word(0,78,111,110)
, bytes2word(83,116,100,71)
, bytes2word(101,116,80,73)
, bytes2word(68,46,103,101)
, bytes2word(116,80,73,68)
, bytes2word(35,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getPID" NonStdGetPID.getPID# 1 :: Prelude.() -> Prelude.Int */
extern HsInt hs_getPID(void);
#ifdef PROFILE
static SInfo pf_NonStdGetPID_46getPID_35 = {"NonStdGetPID","NonStdGetPID.getPID#","Prelude.Int"};
#endif
C_HEADER(FR_NonStdGetPID_46getPID_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = hs_getPID();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NonStdGetPID_46getPID_35);
  C_RETURN(nodeptr);
}
